<?php

namespace Bixo\Chat\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Chat\Actions\ChatAction;
use Bixo\Chat\Http\Requests\ChatActionRequest;
use Bixo\Chat\Http\Resources\ChatResource;
use Bixo\Chat\Models\Chat;

/**
 * Admin web controller class.
 */
class ChatActionController extends BaseController
{

    /**
     * Action controller function for chat.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ChatActionRequest $request, Chat $chat, $action)
    {
        try {
            $request = $request->all();
            $chat = ChatAction::run($action, $chat, $request);

            $data = new ChatResource($chat);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('chat::chat.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('chat/chat/' . $chat->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('chat/chat/' . $chat->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
