<?php

namespace Bixo\Chat\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Chat\Events\ChatAction as ChatActionEvent;
use Bixo\Chat\Notifications\ChatAction as ChatActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ChatAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ChatActionEvent.
     *
     * @param   ChatActionEvent  $event
     * @return mixed
     */
    public function handle(ChatActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $chat.
     *
     * @param   ChatActionEvent  $event
     * @return void
     */
    public function create(ChatActionEvent $event)
    {
        $client = $event->chat->client;
        Notification::send($client, new ChatActionNotification($event));
    }

    /**
     * Handle the ChatActionEvent as a listener.
     *
     * @param   ChatActionEvent  $event
     * @return mixed
     */
    public function asListener(ChatActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ChatActionEvent  $event
     * @return bool
     */
    private function isAllowed(ChatActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
