<?php
namespace Bixo\Chat\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Chat\Events\ChatAction as ChatActionEvent;
use Bixo\Chat\Models\Chat;

class ChatAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $chat;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ChatActionEvent $chat
     */
    public function __construct(ChatActionEvent $chat)
    {
        $this->action = $event->action;
        $this->chat = $chat;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Chat Approved - ' . config('app.name'))
            ->view('chat::chat.email.action', ['data' => $this->chat]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
